@@ -25,22 +25,11 @@
 #include <sys/types.h>
 #include <errno.h>
 
-#include <libguile.h>
-
-#ifndef HAVE_GUILE_1_8
-#include "guile16-compat.h"
-#endif
-
 #include <glib/gi18n.h>
 
+#include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
-#ifdef HAVE_GNOME
-#include <libgnomeui/gnome-help.h>
-#else
-#include <gdk/gdkspawn.h>
-#endif
-
 #ifdef HAVE_HILDON
 #ifdef HAVE_MAEMO_3
 #include <hildon-widgets/hildon-banner.h>
@@ -52,6 +41,7 @@
 #include <libgames-support/games-clock.h>
 #include <libgames-support/games-files.h>
 #include <libgames-support/games-stock.h>
+#include <libgames-support/games-runtime.h>
 #include <libgames-support/games-sound.h>
 
 #include "board.h"
@@ -217,6 +207,7 @@ select_game_cb (GtkAction *action,
   GtkTreeIter current_iter, selection_iter;
   gboolean current_iter_set = FALSE;
   const char *current_game_file;
+  const char *games_dir;
   GList *l;
 
   if (priv->game_choice_dialog) {
@@ -228,7 +219,8 @@ select_game_cb (GtkAction *action,
   list_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list));
   g_object_unref (list);
 
-  files = games_file_list_new ("*.scm", games_path_runtime_fix (GAMESDIR), NULL);
+  games_dir = games_runtime_get_directory (GAMES_RUNTIME_GAME_GAMES_DIRECTORY);
+  files = games_file_list_new ("*.scm", games_dir, NULL);
   games_file_list_transform_basename (files);
 
   current_game_file = aisleriot_game_get_game_file (priv->game);
@@ -610,7 +602,7 @@ help_about_cb (GtkAction *action,
                            NULL :
                            _("AisleRiot provides a rule-based solitaire "
                              "card engine that allows many different "
-                             "games to be played.\n\n"
+                             "games to be played.\n"
 			     "AisleRiot is a part of GNOME Games."),
 #endif
                          "copyright", "Copyright © 1998-2006 Jonathan Blandford\n"
@@ -724,7 +716,12 @@ static void
 delayed_move_to_next_screen_cb (GtkAction *action,
                                 GtkWidget *widget)
 {
+#if GLIB_CHECK_VERSION (2, 14, 0)
+  g_timeout_add_seconds (10, (GSourceFunc) delayed_move_to_next_screen_timeout_cb, widget);
+#else
   g_timeout_add (10 * 1000, (GSourceFunc) delayed_move_to_next_screen_timeout_cb, widget);
+#endif /* GLIB 2.14.0 */
+
 }
 
 static void
@@ -759,12 +756,14 @@ debug_ensure_game_list (AisleriotWindow *window)
   DebugWindowData *data;
   GamesFileList *files;
   GList *l;
+  const char *games_dir;
 
   data = g_object_get_data (G_OBJECT (window), DEBUG_WINDOW_DATA_KEY);
   if (data != NULL)
     return data;
 
-  files = games_file_list_new ("*.scm", games_path_runtime_fix (GAMESDIR), NULL);
+  games_dir = games_runtime_get_directory (GAMES_RUNTIME_GAME_GAMES_DIRECTORY);
+  files = games_file_list_new ("*.scm", games_dir, NULL);
   games_file_list_transform_basename (files);
 
   data = g_slice_new (DebugWindowData);
@@ -1062,14 +1061,30 @@ sound_toggle_cb (GtkToggleAction *action,
   games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SOUND), sound_enabled);
 }
 
+#ifdef HAVE_CLUTTER
+
+static void
+animations_toggle_cb (GtkToggleAction *action,
+                      AisleriotWindow *window)
+{
+  AisleriotWindowPrivate *priv = window->priv;
+  gboolean enabled;
+
+  enabled = gtk_toggle_action_get_active (action);
+
+  aisleriot_board_set_animation_mode (priv->board, enabled);
+  
+  games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_ANIMATIONS), enabled);
+}
+
+#endif /* HAVE_CLUTTER */
+
 static void
 show_hint_cb (GtkAction *action,
               AisleriotWindow *window)
 {
   AisleriotWindowPrivate *priv = window->priv;
-  SCM hint, string1, string2;
-  char *message = NULL;
-  char *str1, *str2;
+  char *message;
 #ifndef HAVE_HILDON
   GtkWidget *dialog;
 #endif
@@ -1088,103 +1103,7 @@ show_hint_cb (GtkAction *action,
   if (aisleriot_game_get_state (priv->game) != GAME_RUNNING)
     return;
 
-  hint = aisleriot_game_hint_lambda (priv->game);
-
-  if (!SCM_NFALSEP (hint)) {
-    message = g_strdup (_("This game does not have hint support yet."));
-  } else {
-    switch (scm_num2int (SCM_CAR (hint), SCM_ARG1, NULL)) {
-
-    case 0:
-      string1 = SCM_CADR (hint);
-      if (!scm_is_string (string1))
-        break;
-
-      str1 = scm_to_locale_string (string1);
-      if (!str1)
-        break;
-
-      message = g_strdup (str1);
-      free (str1);
-      break;
-
-    case 1:
-      string1 = SCM_CADR (hint);
-      string2 = SCM_CADDR (hint);
-
-      if (!scm_is_string (string1) || !scm_is_string (string2))
-        break;
-
-      str1 = scm_to_locale_string (string1);
-      if (!str1)
-        break;
-      str2 = scm_to_locale_string (string2);
-      if (!str2) {
-        free (str1);
-        break;
-      }
-
-      /* Both %s are card names */
-      message = g_strdup_printf (_("Move %s onto %s."), str1, str2);
-      free (str1);
-      free (str2);
-      break;
-
-    case 2:
-      /* NOTE! This case is exactly the same as case 1, but the strings
-        * are different: the first is a card name, the 2nd a sentence fragment.
-        * NOTE! FIXMEchpe! This is bad for i18n.
-        */
-      string1 = SCM_CADR (hint);
-      string2 = SCM_CADDR (hint);
-
-      if (!scm_is_string (string1) || !scm_is_string (string2))
-        break;
-
-      str1 = scm_to_locale_string (string1);
-      if (!str1)
-        break;
-      str2 = scm_to_locale_string (string2);
-      if (!str2) {
-        free (str1);
-        break;
-      }
-
-      /* The first %s is a card name, the 2nd %s a sentence fragment.
-        * Yes, we know this is bad for i18n.
-        */
-      message = g_strdup_printf (_("Move %s onto %s."), str1, str2);
-      free (str1);
-      free (str2);
-      break;
-
-    case 3: /* This is deprecated (due to i18n issues) do not use. */
-      g_warning ("This game uses a deprecated hint method (case 3).\n"
-                 "Please file a bug at http://bugzilla.gnome.org "
-                 "including this message and the name of the game "
-                 "you were playing, which is %s.\n",
-                 aisleriot_game_get_game_file (priv->game));
-      break;
-
-    case 4:
-      string1 = SCM_CADR (hint);
-      if (!scm_is_string (string1))
-        break;
-
-      str1 = scm_to_locale_string (string1);
-      if (!str1)
-        break;
-
-      message = g_strdup_printf (_("You are searching for a %s."), str1);
-      free (str1);
-      break;
-
-    default:
-      message = g_strdup (_("This game is unable to provide a hint."));
-      break;
-    }
-  }
-
+  message = aisleriot_game_get_hint (priv->game);
   if (!message)
     return;
 
@@ -1223,56 +1142,36 @@ deal_cb (GtkAction *action,
   aisleriot_game_deal_cards (priv->game);
 }
 
-/* Make something that's easier to store in conf */
-static guint
-compress_options_to_int (SCM options_list)
-{
-  int i;
-  guint bits;
-  SCM entry;
-
-  bits = 0;
-  for (i = scm_to_int (scm_length (options_list)) - 1; i >= 0; i--) {
-    entry = scm_list_ref (options_list, scm_from_int (i));
-    if (SCM_NFALSEP (scm_list_p (entry))) {
-      bits <<= 1;
-      bits |= SCM_NFALSEP (scm_list_ref (entry, scm_from_int (1))) ? 1 : 0;
-    }
-  }
-
-  return bits;
-}
-
-/* Take the bit-string value and set the option list from it. */
-static void
-expand_options_from_int (SCM options_list, guint bits)
-{
-  gint l, i;
-  SCM entry;
-
-  l = scm_to_int (scm_length (options_list));
-  for (i = 0; i < l; i++) {
-    entry = scm_list_ref (options_list, scm_from_int (i));
-    if (SCM_NFALSEP (scm_list_p (entry))) {
-      scm_list_set_x (entry, scm_from_int (1),
-		      bits & 1 ? SCM_BOOL_T : SCM_BOOL_F);
-      bits >>= 1;
-    }
-  }
-}
-
 /* The "Game Options" menu */
 
+static void
+apply_option (GtkToggleAction *action,
+              guint32 *changed_mask,
+              guint32 *changed_value)
+{
+  gboolean active;
+  const char *action_name;
+  guint32 value;
+
+  active = gtk_toggle_action_get_active (action);
+
+  action_name = gtk_action_get_name (GTK_ACTION (action));
+  value = g_ascii_strtoull (action_name + strlen ("Option"), NULL, 16);
+
+  g_print ("option %s changed, value=%x set=%d\n", action_name, value, active);
+
+  *changed_mask |= value;
+  if (active)
+    *changed_value |= value;
+}
+
 static void
 option_cb (GtkToggleAction *action,
            AisleriotWindow *window)
 {
   AisleriotWindowPrivate *priv = window->priv;
-  SCM options_list;
-  SCM entry;
   gboolean active;
-  const char *action_name;
-  guint n;
+  guint32 changed_mask = 0, changed_value = 0, value;
 
   /* Don't change the options if we're just installing the options menu */
   if (priv->changing_game_type)
@@ -1280,31 +1179,36 @@ option_cb (GtkToggleAction *action,
 
   active = gtk_toggle_action_get_active (action);
 
-  action_name = gtk_action_get_name (GTK_ACTION (action));
-  n = g_ascii_strtoull (action_name + strlen ("Option"), NULL, 10);
-
-  options_list = aisleriot_game_get_options_lambda (priv->game);
-
-  entry = scm_list_ref (options_list, scm_from_uint (n));
-
-  scm_list_set_x (entry, scm_from_uint (1), active ? SCM_BOOL_T : SCM_BOOL_F);
-
-  aisleriot_conf_set_options (aisleriot_game_get_game_file (priv->game),
-                              compress_options_to_int (options_list));
-                              
-  aisleriot_game_apply_options_lambda (priv->game, options_list);
-
   /* If we're toggling OFF a radio action, don't redeal now,
    * since we'll get called another time right again when the new option
    * is toggled ON.
-   * (Note that we _cannot_ also skip applying the options above, since
-   * otherwise the bit from the old option won't get cleared, leading to
-   * wrong game behaviour e.g. in Klondike.)
+   * The game options will be updated when we get the toggled signal
+   * for the newly active action in this group.
    */
   if (GTK_IS_RADIO_ACTION (action) &&
       !active)
     return;
 
+  if (GTK_IS_RADIO_ACTION (action)) {
+    GSList *group, *l;
+
+    /* If toggling ON a radio action, we didn't turn off the other option
+     * earlier. So we need to refresh the whole group.
+     */
+
+    group = gtk_radio_action_get_group (GTK_RADIO_ACTION (action));
+
+    for (l = group; l; l = l->next) {
+      apply_option (GTK_TOGGLE_ACTION (l->data), &changed_mask, &changed_value);
+    }
+  } else {
+    apply_option (action, &changed_mask, &changed_value);
+  }
+
+  value = aisleriot_game_change_options (priv->game, changed_mask, changed_value);
+
+  aisleriot_conf_set_options (aisleriot_game_get_game_file (priv->game), (int) value);
+
   /* Now re-deal, so the option is applied */
   aisleriot_game_new_game (priv->game, NULL);
 }
@@ -1313,10 +1217,10 @@ static void
 install_options_menu (AisleriotWindow *window)
 {
   AisleriotWindowPrivate *priv = window->priv;
-  SCM options_list;
-  int l, i, options;
-  gint mode = OPTION_CHECKMENU;
+  GList *options, *l;
+  int options_value = 0;
   GSList *radiogroup = NULL;
+  int radion = 0;
 
   if (priv->options_merge_id != 0) {
     gtk_ui_manager_remove_ui (priv->ui_manager, priv->options_merge_id);
@@ -1331,99 +1235,74 @@ install_options_menu (AisleriotWindow *window)
   /* See gtk bug #424448 */
   gtk_ui_manager_ensure_update (priv->ui_manager);
 
+  /* Only apply the options if they exist. Otherwise the options in the menu
+   * and the real game options are out of sync until first changed by the user.
+   */
+  if (aisleriot_conf_get_options (aisleriot_game_get_game_file (priv->game), &options_value)) {
+    aisleriot_game_change_options (priv->game, AISLERIOT_GAME_OPTIONS_MAX, options_value);
+  }
+
   /* To get radio buttons in the menu insert an atom into the option list
    * in your scheme code. To get back out of radio-button mode insert 
    * another atom. The exact value of the atoms is irrelevant - they merely
    * trigger a toggle - but descriptive names like begin-exclusive and
    * end-exclusive are probably a good idea.
    */
-  options_list = aisleriot_game_get_options_lambda (priv->game);
-
-  if (scm_is_false (scm_list_p (options_list)))
+  options = aisleriot_game_get_options (priv->game);
+  if (!options)
     return;
-    
+
   priv->options_group = gtk_action_group_new ("Options");
   gtk_ui_manager_insert_action_group (priv->ui_manager, priv->options_group, -1);
   g_object_unref (priv->options_group);
 
   priv->options_merge_id = gtk_ui_manager_new_merge_id (priv->ui_manager);
 
-  /* Only apply the options if they exist. Otherwise the options in the menu
-    * and the real game options are out of sync until first changed by the user.
-    */
-  if (aisleriot_conf_get_options (aisleriot_game_get_game_file (priv->game), &options)) {
-    expand_options_from_int (options_list, options);
-    aisleriot_game_apply_options_lambda (priv->game, options_list);
-  }
+  for (l = options; l != NULL; l = l->next) {
+    AisleriotGameOption *option = (AisleriotGameOption *) l->data;
+    GtkToggleAction *action;
+    gchar actionname[32];
 
-  l = scm_to_int (scm_length (options_list));
-  for (i = 0; i < l; i++) {
-    SCM entry;
+    g_print ("installing option value=%08x set=%d type=%d name='%s'\n",
+             option->value, option->set, option->type, option->display_name);
 
-    /* Each entry in the options list is a list consisting of a name and
-     * a variable.
-     */
-    entry = scm_list_ref (options_list, scm_from_int (i));
-    if (!scm_is_false (scm_list_p (entry))) {
-      SCM entryname;
-      char *entrynamestr;
-      gboolean entrystate;
-      GtkToggleAction *action;
-      gchar actionname[32];
+    g_snprintf (actionname, sizeof (actionname), "Option%u", option->value);
 
-      entryname = scm_list_ref (entry, scm_from_uint (0));
-      if (!scm_is_string (entryname))
-        continue; /* Shouldn't happen */
-
-      entrynamestr = scm_to_locale_string (entryname);
-      if (!entrynamestr)
-        continue;
-
-      entrystate = SCM_NFALSEP (scm_list_ref (entry, scm_from_uint (1)));
-
-      g_snprintf (actionname, sizeof (actionname), "Option%d", i);
-
-      if (mode == OPTION_CHECKMENU) {
-        action = gtk_toggle_action_new (actionname,
-                                        entrynamestr,
-                                        NULL,
-                                        NULL /* tooltip */);
-      } else {
-        action = GTK_TOGGLE_ACTION (gtk_radio_action_new (actionname,
-                                                          entrynamestr,
-                                                          NULL,
-                                                          NULL /* tooltip */,
-                                                          i));
-        gtk_radio_action_set_group (GTK_RADIO_ACTION (action),
-                                    radiogroup);
-        radiogroup = gtk_radio_action_get_group (GTK_RADIO_ACTION (action));
-      }
-
-      free (entrynamestr);
-
-      gtk_toggle_action_set_active (action, entrystate);
-      g_signal_connect (action, "toggled",
-                        G_CALLBACK (option_cb), window);
-
-      gtk_action_group_add_action (priv->options_group, GTK_ACTION (action));
-      g_object_unref (action);
-
-      gtk_ui_manager_add_ui (priv->ui_manager,
-                             priv->options_merge_id,
-                             OPTIONS_MENU_PATH,
-                             actionname, actionname,
-                             GTK_UI_MANAGER_MENUITEM, FALSE);
+    if (option->type == AISLERIOT_GAME_OPTION_CHECK) {
+      action = gtk_toggle_action_new (actionname,
+                                      option->display_name,
+                                      NULL,
+                                      NULL /* tooltip */);
+      radiogroup = NULL; /* make sure to start a new radio group when the next RADIO option comes */
+      radion = 0;
     } else {
-      /* If we encounter an atom, change the mode. What the atom is doesn't
-      * really matter. */
-      if (mode == OPTION_CHECKMENU) {
-        mode = OPTION_RADIOMENU;
-        radiogroup = NULL;	/* Start a new radio group. */
-      } else {
-        mode = OPTION_CHECKMENU;
-      }
+      action = GTK_TOGGLE_ACTION (gtk_radio_action_new (actionname,
+                                                        option->display_name,
+                                                        NULL,
+                                                        NULL /* tooltip */,
+                                                        radion++));
+      gtk_radio_action_set_group (GTK_RADIO_ACTION (action),
+                                  radiogroup);
+      radiogroup = gtk_radio_action_get_group (GTK_RADIO_ACTION (action));
     }
+
+    gtk_toggle_action_set_active (action, option->set);
+    g_signal_connect (action, "toggled",
+                      G_CALLBACK (option_cb), window);
+
+    gtk_action_group_add_action (priv->options_group, GTK_ACTION (action));
+    g_object_unref (action);
+
+    gtk_ui_manager_add_ui (priv->ui_manager,
+                           priv->options_merge_id,
+                           OPTIONS_MENU_PATH,
+                           actionname, actionname,
+                           GTK_UI_MANAGER_MENUITEM, FALSE);
+
+    aisleriot_game_option_free (option);
   }
+
+  g_list_free (options);
 }
 
 /* The "Recent Games" menu */
@@ -1528,7 +1407,7 @@ install_recently_played_menu (AisleriotWindow *window)
 #ifdef HAVE_HILDON
     tooltip = NULL;
 #else
-    tooltip = g_strdup_printf (_("Play \"%s\""), game_name);
+    tooltip = g_strdup_printf (_("Play “%s”"), game_name);
 #endif /* HAVE_HILDON */
     action = gtk_action_new (actionname, game_name, tooltip, NULL);
     g_free (game_name);
@@ -1632,7 +1511,7 @@ install_card_theme_menu (AisleriotWindow *window)
 #ifdef HAVE_HILDON
     tooltip = NULL;
 #else
-    tooltip = g_strdup_printf (_("Display cards with \"%s\" card theme"), display_name);
+    tooltip = g_strdup_printf (_("Display cards with “%s” card theme"), display_name);
 #endif
     action = gtk_radio_action_new (actionname, display_name, tooltip, NULL, i);
     g_free (display_name);
@@ -1995,6 +1874,52 @@ game_exception_cb (AisleriotGame *game,
   gtk_widget_show (dialog);
 }
 
+#ifdef HAVE_CLUTTER
+
+static void
+settings_changed_cb (GtkSettings *settings,
+                     GParamSpec *pspec,
+                     AisleriotWindow *window)
+{
+  AisleriotWindowPrivate *priv = window->priv;
+  GtkAction *action;
+  gboolean enabled;
+
+  g_object_get (settings, "gtk-enable-animations", &enabled, NULL);
+
+  action = gtk_action_group_get_action (priv->action_group, "Animations");
+  gtk_action_set_visible (action, enabled);
+}
+
+static void
+screen_changed_cb (GtkWidget *widget,
+                   GdkScreen *previous_screen,
+                   AisleriotWindow *window)
+{
+  GdkScreen *screen;
+  GtkSettings *settings;
+
+  screen = gtk_widget_get_screen (widget);
+  if (screen == previous_screen)
+    return;
+
+  if (previous_screen) {
+    g_signal_handlers_disconnect_by_func (gtk_settings_get_for_screen (previous_screen),
+                                          G_CALLBACK (settings_changed_cb),
+                                          window);
+  }
+  
+  if (screen == NULL)
+    return;
+
+  settings = gtk_widget_get_settings (widget);
+  settings_changed_cb (settings, NULL, window);
+  g_signal_connect (settings, "notify::gtk-enable-animations",
+                    G_CALLBACK (settings_changed_cb), window);
+}
+  
+#endif /* HAVE_CLUTTER */
+
 /* Class implementation */
 
 #ifdef HAVE_HILDON
@@ -2174,10 +2099,16 @@ aisleriot_window_init (AisleriotWindow *window)
       ACTION_TOOLTIP (N_("Pick up and drop cards by clicking")),
       G_CALLBACK (clickmove_toggle_cb),
       FALSE /* not active by default */ },
-   { "Sound", NULL, N_("_Enable sounds"), NULL,
-      ACTION_TOOLTIP (N_("Whether or not to play event sounds.")),
+   { "Sound", NULL, N_("_Sound"), NULL,
+      ACTION_TOOLTIP (N_("Whether or not to play event sounds")),
       G_CALLBACK (sound_toggle_cb),
       FALSE /* not active by default */ },
+#ifdef HAVE_CLUTTER
+   { "Animations", NULL, N_("_Animations"), NULL,
+      ACTION_TOOLTIP (N_("Whether or not to animate card moves")),
+      G_CALLBACK (animations_toggle_cb),
+      FALSE /* not active by default */ },
+#endif /* HAVE_CLUTTER */
 #ifdef ENABLE_DEBUG_UI
     { "DebugPixbufDrawing", NULL, "_Pixbuf drawing", NULL, NULL,
       G_CALLBACK (debug_pixbuf_drawing_cb),
@@ -2270,6 +2201,9 @@ aisleriot_window_init (AisleriotWindow *window)
           "<separator/>"
           "<menuitem action='ClickToMove'/>"
           "<menuitem action='Sound'/>"
+#ifdef HAVE_CLUTTER
+          "<menuitem action='Animations'/>"
+#endif
         "</menu>"
         "<menu action='OptionsMenu'/>"
         "<menu action='HelpMenu'>"
@@ -2306,7 +2240,7 @@ aisleriot_window_init (AisleriotWindow *window)
         "<toolitem action='Deal'/>"
         "<toolitem action='Hint'/>"
 #ifndef HAVE_MAEMO
-        "<toolitem action='Fullscreen'/>"
+        "<toolitem action='LeaveFullscreen'/>"
 #endif
 #ifdef ENABLE_DEBUG_UI
         "<toolitem action='DebugGameFirst'/>"
@@ -2524,6 +2458,15 @@ aisleriot_window_init (AisleriotWindow *window)
 
   set_fullscreen_actions (window, FALSE);
 
+#ifdef HAVE_CLUTTER
+  action = gtk_action_group_get_action (priv->action_group, "Animations");
+  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
+                                games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_ANIMATIONS), NULL));
+
+  /* Set the action visibility and listen for animation mode changes */
+  screen_changed_cb (GTK_WIDGET (window), NULL, window);
+#endif /* HAVE_CLUTTER */
+
   /* Now set up the widgets */
   main_vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (window), main_vbox);
@@ -2608,6 +2551,12 @@ aisleriot_window_finalize (GObject *object)
   AisleriotWindow *window = AISLERIOT_WINDOW (object);
   AisleriotWindowPrivate *priv = window->priv;
 
+#ifdef HAVE_CLUTTER
+  g_signal_handlers_disconnect_by_func (gtk_widget_get_settings (GTK_WIDGET (window)),
+                                        G_CALLBACK (settings_changed_cb),
+                                        window);
+#endif /* HAVE_CLUTTER */
+
 #ifndef HAVE_HILDON
   if (priv->hint_dialog) {
     gtk_widget_destroy (priv->hint_dialog);
@@ -2723,7 +2672,7 @@ load_idle_cb (LoadIdleData *data)
                                      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                      GTK_MESSAGE_ERROR,
                                      GTK_BUTTONS_OK,
-                                     _("Cannot start the game \"%s\""),
+                                     _("Cannot start the game “%s”"),
                                      name);
     g_free (name);
 
