@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 """
 
@@ -94,6 +95,7 @@ class ChessGame(game.ChessGame):
 
         self.view.showMoveHints(config.get('show_move_hints') is True)
         self.view.showBoardNumbering(config.get('show_numbering') is True)
+        self.view.showSmooth(config.get('show_3d_smooth') is True)        
         
         # Watch for piece moves with a player
         self.__movePlayer = player.MovePlayer(self)
@@ -110,6 +112,9 @@ class ChessGame(game.ChessGame):
         
         Returns an AI player to use (game.ChessPlayer).
         """
+        # Translators: Description of an AI player used in log window. %(name)s is replaced with
+        # the name of the AI player. %(game)s is replaced with the name of the game the AI player
+        # is in.
         description = _("'%(name)s' in '%(game)s'") % {'name': name, 'game': self.name}
         p = player.AIPlayer(self.application, name, profile, level, description)
         self.__aiPlayers.append(p)
@@ -442,7 +447,9 @@ class Application:
         
         self.history = history.GameHistory()
         
-        self.logger = self.ui.controller.addLogWindow(_('Application Log'), '', '')
+        # Translators: Name of the log that displays application events
+        title = _('Application Log')
+        self.logger = self.ui.controller.addLogWindow(title, '', '')
 
     def addAIProfile(self, profile):
         """Add a new AI profile into glChess.
@@ -687,6 +694,8 @@ class Application:
             self.logger.addLine('loaded in %f seconds' % (time.time() - s))
 
         else:
+            # FIXME: Should be in a dialog
+            # Translators: Text displayed on the command-line if an unknown argument is passed
             print _('Usage: %s [game]') % sys.argv[0]
             sys.exit(0)
 
@@ -697,8 +706,13 @@ class Application:
                     aiName = p.name
                     break
             black = (aiName, 'easy')
-            name = _('Human versus %s') % aiName
-            g = self.addLocalGame(name, _('White'), None, _('Black'), black)
+            # Translators: Name of a human versus AI game. The %s is replaced with the name of the AI player
+            gameName = _('Human versus %s') % aiName
+            # Translators: Name of white player in a default game
+            whiteName =  _('White')
+            # Translators: Name of black player in a default game            
+            blackName = _('Black')
+            g = self.addLocalGame(gameName, whiteName, None, blackName, black)
             g.inHistory = True
             g.start()
 
@@ -706,8 +720,9 @@ class Application:
         try:
             self.ui.controller.run()
         except:
-            print _('glChess has crashed. Please report this bug to http://bugzilla.gnome.org')
-            print _('Debug output:')
+            # FIXME: Isn't this done by bug-buddy?
+            print _("""glChess has crashed. Please report this bug to http://bugzilla.gnome.org
+Debug output:""")
             print traceback.format_exc()
             self.quit()
             sys.exit(1)
